@@ -2,7 +2,6 @@
 #
 # vim: ts=4 sw=4 nowrap
 #
-from __future__ import print_function
 
 """PKI demo by Peter Teniz <peter.teniz@inverisa.net>"""
 
@@ -17,9 +16,9 @@ MBSTRING_BMP = MBSTRING_FLAG | 2
 class Cert(object):
     def __init__(self):
         self.RsaKey = {
-            'KeyLength': 1024,
-            'PubExponent': 0x10001,  # -> 65537
-            'keygen_callback': self.callback,
+            "KeyLength": 1024,
+            "PubExponent": 0x10001,  # -> 65537
+            "keygen_callback": self.callback,
         }
 
         self.KeyPair = None
@@ -29,23 +28,23 @@ class Cert(object):
         self.X509Certificate = None
 
     def callback(self, *args):
-        return 'p'
+        return "p"
 
     def CreatePKey(self):
         self.KeyPair = RSA.gen_key(
-            self.RsaKey['KeyLength'],
-            self.RsaKey['PubExponent'],
-            self.RsaKey['keygen_callback'],
+            self.RsaKey["KeyLength"],
+            self.RsaKey["PubExponent"],
+            self.RsaKey["keygen_callback"],
         )
         # PubKey = RSA.new_pub_key( self.KeyPair.pub () )
 
         self.KeyPair.save_key(
-            'KeyPair.pem',
-            cipher='des_ede3_cbc',
+            "KeyPair.pem",
+            cipher="des_ede3_cbc",
             callback=self.callback,
         )
 
-        self.PKey = EVP.PKey(md='sha1')
+        self.PKey = EVP.PKey(md="sha1")
         self.PKey.assign_rsa(self.KeyPair)
 
     def CreateX509Request(self):
@@ -62,65 +61,65 @@ class Cert(object):
         X509Name = X509.X509_Name()
 
         X509Name.add_entry_by_txt(
-            field='C',
+            field="C",
             type=MBSTRING_ASC,
-            entry='austria',
+            entry="austria",
             len=-1,
             loc=-1,
             set=0,
         )  # country name
         X509Name.add_entry_by_txt(
-            field='SP',
+            field="SP",
             type=MBSTRING_ASC,
-            entry='kernten',
+            entry="kernten",
             len=-1,
             loc=-1,
             set=0,
         )  # state of province name
         X509Name.add_entry_by_txt(
-            field='L',
+            field="L",
             type=MBSTRING_ASC,
-            entry='stgallen',
+            entry="stgallen",
             len=-1,
             loc=-1,
             set=0,
         )  # locality name
         X509Name.add_entry_by_txt(
-            field='O',
+            field="O",
             type=MBSTRING_ASC,
-            entry='labor',
+            entry="labor",
             len=-1,
             loc=-1,
             set=0,
         )  # organization name
         X509Name.add_entry_by_txt(
-            field='OU',
+            field="OU",
             type=MBSTRING_ASC,
-            entry='it-department',
+            entry="it-department",
             len=-1,
             loc=-1,
             set=0,
         )  # organizational unit name
         X509Name.add_entry_by_txt(
-            field='CN',
+            field="CN",
             type=MBSTRING_ASC,
-            entry='Certificate client',
+            entry="Certificate client",
             len=-1,
             loc=-1,
             set=0,
         )  # common name
         X509Name.add_entry_by_txt(
-            field='Email',
+            field="Email",
             type=MBSTRING_ASC,
-            entry='user@localhost',
+            entry="user@localhost",
             len=-1,
             loc=-1,
             set=0,
         )  # pkcs9 email address
         X509Name.add_entry_by_txt(
-            field='emailAddress',
+            field="emailAddress",
             type=MBSTRING_ASC,
-            entry='user@localhost',
+            entry="user@localhost",
             len=-1,
             loc=-1,
             set=0,
@@ -133,7 +132,7 @@ class Cert(object):
         #
 
         self.X509Request.set_pubkey(pkey=self.PKey)
-        self.X509Request.sign(pkey=self.PKey, md='sha1')
+        self.X509Request.sign(pkey=self.PKey, md="sha1")
         # print(X509Request.as_text ())
 
     def CreateX509Certificate(self):
@@ -189,65 +188,65 @@ class Cert(object):
         X509Name = X509.X509_Name(m2.x509_name_new())
 
         X509Name.add_entry_by_txt(
-            field='C',
+            field="C",
             type=MBSTRING_ASC,
-            entry='germany',
+            entry="germany",
             len=-1,
             loc=-1,
             set=0,
         )  # country name
         X509Name.add_entry_by_txt(
-            field='SP',
+            field="SP",
             type=MBSTRING_ASC,
-            entry='bavaria',
+            entry="bavaria",
             len=-1,
             loc=-1,
             set=0,
         )  # state of province name
         X509Name.add_entry_by_txt(
-            field='L',
+            field="L",
             type=MBSTRING_ASC,
-            entry='munich',
+            entry="munich",
             len=-1,
             loc=-1,
             set=0,
         )  # locality name
         X509Name.add_entry_by_txt(
-            field='O',
+            field="O",
             type=MBSTRING_ASC,
-            entry='sbs',
+            entry="sbs",
             len=-1,
             loc=-1,
             set=0,
         )  # organization name
         X509Name.add_entry_by_txt(
-            field='OU',
+            field="OU",
             type=MBSTRING_ASC,
-            entry='it-department',
+            entry="it-department",
             len=-1,
             loc=-1,
             set=0,
         )  # organizational unit name
         X509Name.add_entry_by_txt(
-            field='CN',
+            field="CN",
             type=MBSTRING_ASC,
-            entry='Certificate Authority',
+            entry="Certificate Authority",
             len=-1,
             loc=-1,
             set=0,
         )  # common name
         X509Name.add_entry_by_txt(
-            field='Email',
+            field="Email",
             type=MBSTRING_ASC,
-            entry='admin@localhost',
+            entry="admin@localhost",
             len=-1,
             loc=-1,
             set=0,
         )  # pkcs9 email address
         X509Name.add_entry_by_txt(
-            field='emailAddress',
+            field="emailAddress",
             type=MBSTRING_ASC,
-            entry='admin@localhost',
+            entry="admin@localhost",
             len=-1,
             loc=-1,
             set=0,
@@ -262,11 +261,11 @@ class Cert(object):
         # signing
         #
 
-        self.X509Certificate.sign(pkey=self.PKey, md='sha1')
+        self.X509Certificate.sign(pkey=self.PKey, md="sha1")
         print(self.X509Certificate.as_text())
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     run = Cert()
     run.CreatePKey()
     run.CreateX509Request()
