@@ -3,8 +3,7 @@
 Copyright (c) 1999-2001 Ng Pheng Siong. All rights reserved.
 This software is released under the ZPL. Usual disclaimers apply."""
 
-RCS_id = '$Id: SmimeTag.py 299 2005-06-09 17:32:28Z heikki $'
-__version__ = '$Revision: 1.2 $'[11:-2]
+__version__ = "1.2"
 
 # Zope tag stuff.
 from DocumentTemplate.DT_String import String
@@ -16,10 +15,11 @@ from M2Crypto import BIO, SMIME, X509
 
 SmimeError = "SmimeTag Error"
 
+
 class SmimeTag:
     """<dtml-smime>"""
 
-    name = 'smime'
+    name = "smime"
     blockContinuations = ()
 
     def __init__(self, blocks):
@@ -29,24 +29,23 @@ class SmimeTag:
         args = parse_params(args, signer=None, recipients=None)
         has_key = args.has_key
 
-        if has_key('signer'):
-            self.signer = args['signer']
+        if has_key("signer"):
+            self.signer = args["signer"]
             try:
                 Call(self.signer)
             except ParseError:
-                raise SmimeError, ('Invalid parameter "signer".')
+                raise SmimeError('Invalid parameter "signer".')
         else:
-            raise SmimeError, ('The parameter "signer" was not specified in tag.')
+            raise SmimeError('The parameter "signer" was not specified in tag.')
 
-        if has_key('recipients'):
-            self.recipients = args['recipients']
+        if has_key("recipients"):
+            self.recipients = args["recipients"]
             try:
                 Call(self.recipients)
             except ParseError:
-                raise SmimeError, ('Invalid parameter "recipients".')
+                raise SmimeError('Invalid parameter "recipients".')
         else:
-            raise SmimeError, ('The parameter "recipients" was not specified in tag.')
-
+            raise SmimeError('The parameter "recipients" was not specified in tag.')
 
     def render(self, md):
         # Render the dtml block.
@@ -56,14 +55,14 @@ class SmimeTag:
         # Prepare to S/MIME.
         s = SMIME.SMIME()
 
-        # Render the signer key, load into BIO. 
+        # Render the signer key, load into BIO.
         try:
             signer = Var(self.signer).render(md)
         except ParseError:
-            raise SmimeError, ('Invalid parameter "signer".')
+            raise SmimeError('Invalid parameter "signer".')
         signer_key_bio = BIO.MemoryBuffer(signer)
-        signer_cert_bio = BIO.MemoryBuffer(signer) # XXX Kludge.
-        
+        signer_cert_bio = BIO.MemoryBuffer(signer)  # XXX Kludge.
+
         # Sign the data.
         s.load_key_bio(signer_key_bio, signer_cert_bio)
         p7 = s.sign(data_bio, flags=SMIME.PKCS7_TEXT)
@@ -76,7 +75,7 @@ class SmimeTag:
         try:
             recip = Var(self.recipients).render(md)
         except ParseError:
-            raise SmimeError, ('Invalid parameter "recipients".')
+            raise SmimeError('Invalid parameter "recipients".')
         recip_bio = BIO.MemoryBuffer(recip)
 
         # Load recipient certificates.
@@ -85,7 +84,7 @@ class SmimeTag:
         s.set_x509_stack(sk)
 
         # Set a cipher.
-        s.set_cipher(SMIME.Cipher('des_ede3_cbc'))
+        s.set_cipher(SMIME.Cipher("des_ede3_cbc"))
 
         # Encrypt.
         tmp_bio = BIO.MemoryBuffer()
@@ -97,9 +96,7 @@ class SmimeTag:
         s.write(out, p7)
         return out.getvalue()
 
-
     __call__ = render
 
 
-String.commands['smime'] = SmimeTag
-
+String.commands["smime"] = SmimeTag
