@@ -1,20 +1,20 @@
 #!/usr/bin/env python
 
 """
-This is a very simple program to manage the access_x509 database. The 
+This is a very simple program to manage the access_x509 database. The
 overriding goal is program portability, hence its use of 'anydbm'.
 
 Invoke it thusly:
 
-    x509_user.py 
-        -u <username> 
+    x509_user.py
+        -u <username>
         [ -x <X.509 subject DN> ]
-        [ -f <database> ] 
+        [ -f <database> ]
 
 <username> is the Zope username; it must be present.
 
 <X.509 subject DN> is the X.509 certificate's subject distinguished name
-to associate with the user. If it is present, the association is created 
+to associate with the user. If it is present, the association is created
 or updated. If it is absent, the association is removed.
 
 <database> defaults to 'access_x509'.
@@ -22,7 +22,7 @@ or updated. If it is absent, the association is removed.
 (I told you this is a dumb program.)
 
 
-To read the subject distinguished name from the certificate 'client.pem', 
+To read the subject distinguished name from the certificate 'client.pem',
 invoke 'openssl' thusly:
 
     openssl x509 -subject -noout -in client.pem
@@ -43,28 +43,26 @@ This associates the user who owns client.pem to the Zope "superuser".
 Copyright (c) 2000 Ng Pheng Siong. This program is released under the ZPL.
 """
 
-RCS_id='$Id: x509_user.py 299 2005-06-09 17:32:28Z heikki $'
-
 import anydbm, getopt, sys
 
-x509_db = 'access_x509'
+x509_db = "access_x509"
 username = subject_dn = None
 
-argerr='Usage'
+argerr = "Usage"
 
-optlist, optarg=getopt.getopt(sys.argv[1:], 'f:u:x:')   # ;-)
+optlist, optarg = getopt.getopt(sys.argv[1:], "f:u:x:")  # ;-)
 for opt in optlist:
-    if '-f' in opt:
+    if "-f" in opt:
         x509_db = opt[1]
-    elif '-u' in opt:
+    elif "-u" in opt:
         username = opt[1]
-    elif '-x' in opt:
+    elif "-x" in opt:
         subject_dn = opt[1]
 
 if username is None:
-    raise argerr, '\n' + __doc__
+    raise argerr("\n" + __doc__)
 
-db = anydbm.open(x509_db, 'cw')
+db = anydbm.open(x509_db, "cw")
 if subject_dn is None:
     # Remove the association...
     try:
@@ -78,4 +76,3 @@ else:
     db[subject_dn] = username
     db[username] = subject_dn
 db.close()
-
