@@ -1,15 +1,14 @@
 #!/usr/bin/env python
 
-"""A https server built on Medusa's http_server. 
+"""A https server built on Medusa's http_server.
 
 Copyright (c) 1999-2004 Ng Pheng Siong. All rights reserved."""
 
-RCS_id='$Id: https_server.py 299 2005-06-09 17:32:28Z heikki $'
-
 import asynchat, asyncore, http_server, socket, sys
 from M2Crypto import SSL, version
 
-VERSION_STRING=version
+VERSION_STRING = version
+
 
 class https_channel(http_server.http_channel):
 
@@ -26,40 +25,40 @@ class https_channel(http_server.http_channel):
             else:
                 self.server.bytes_out.increment(result)
                 return result
-        except SSL.SSLError, why:
+        except SSL.SSLError as why:
             self.close()
-            self.log_info('send: closing channel %s %s' % (repr(self), why))
+            self.log_info("send: closing channel %s %s" % (repr(self), why))
             return 0
 
     def recv(self, buffer_size):
         try:
             result = self.socket._read_nbio(buffer_size)
             if result is None:
-                return ''
-            elif result == '':
+                return ""
+            elif result == "":
                 self.close()
-                return ''
+                return ""
             else:
                 self.server.bytes_in.increment(len(result))
                 return result
-        except SSL.SSLError, why:
+        except SSL.SSLError as why:
             self.close()
-            self.log_info('recv: closing channel %s %s' % (repr(self), why))
-            return ''
+            self.log_info("recv: closing channel %s %s" % (repr(self), why))
+            return ""
 
 
 class https_server(http_server.http_server):
 
-    SERVER_IDENT='M2Crypto HTTPS Server (v%s)' % VERSION_STRING
+    SERVER_IDENT = "M2Crypto HTTPS Server (v%s)" % VERSION_STRING
 
-    channel_class=https_channel
+    channel_class = https_channel
 
     def __init__(self, ip, port, ssl_ctx, resolver=None, logger_object=None):
         http_server.http_server.__init__(self, ip, port, resolver, logger_object)
-        sys.stdout.write(self.SERVER_IDENT + '\n\n')
+        sys.stdout.write(self.SERVER_IDENT + "\n\n")
         sys.stdout.flush()
-        self.ssl_ctx=ssl_ctx
-        
+        self.ssl_ctx = ssl_ctx
+
     def handle_accept(self):
         # Cribbed from http_server.
         self.total_clients.increment()
@@ -70,12 +69,12 @@ class https_server(http_server.http_server):
             # accept.  socketmodule.c:makesockaddr complains that the
             # address family is unknown.  We don't want the whole server
             # to shut down because of this.
-            sys.stderr.write ('warning: server accept() threw an exception\n')
+            sys.stderr.write("warning: server accept() threw an exception\n")
             return
 
         # Turn the vanilla socket into an SSL connection.
         try:
-            ssl_conn=SSL.Connection(self.ssl_ctx, conn)
+            ssl_conn = SSL.Connection(self.ssl_ctx, conn)
             ssl_conn._setup_ssl(addr)
             ssl_conn.accept_ssl()
             self.channel_class(self, ssl_conn, addr)
@@ -84,4 +83,3 @@ class https_server(http_server.http_server):
 
     def writeable(self):
         return 0
-
