@@ -1,14 +1,15 @@
 #!/usr/bin/env python
 
+from __future__ import print_function
+
 """S/MIME demo.
 
 Copyright (c) 2000 Ng Pheng Siong. All rights reserved."""
 
-RCS_id='$Id: unsmime.py 299 2005-06-09 17:32:28Z heikki $'
-
 from M2Crypto import BIO, Rand, SMIME, X509
 import sys
 
+
 def decrypt_verify(p7file, recip_key, signer_cert, ca_cert):
     s = SMIME.SMIME()
 
@@ -42,11 +43,10 @@ def decrypt_verify(p7file, recip_key, signer_cert, ca_cert):
         # M2Crypto's sendsmime.py opaque-signs, when also encrypting.
         data = s.verify(p7)
 
-    print data
+    print(data)
 
 
-if __name__ == '__main__':
-    Rand.load_file('../randpool.dat', -1) 
-    decrypt_verify(BIO.File(sys.stdin), 'client.pem', 'client2.pem','ca.pem')
-    Rand.save_file('../randpool.dat')
-
+if __name__ == "__main__":
+    Rand.load_file("../randpool.dat", -1)
+    decrypt_verify(BIO.File(sys.stdin), "client.pem", "client2.pem", "ca.pem")
+    Rand.save_file("../randpool.dat")
