@@ -4,33 +4,31 @@
 
 Copyright (c) 1999-2003 Ng Pheng Siong. All rights reserved."""
 
-RCS_id='$Id: c.py 299 2005-06-09 17:32:28Z heikki $'
-
 from socket import *
 import sys
 
 from M2Crypto import SSL, m2
 
-HOST = '127.0.0.1'
+HOST = "127.0.0.1"
 PORT = 9443
-req_10 = 'GET / HTTP/1.0\r\n\r\n'
-req_11 = 'GET / HTTP/1.1\r\nHost: localhost\r\nConnection: close\r\n\r\n'
+req_10 = "GET / HTTP/1.0\r\n\r\n"
+req_11 = "GET / HTTP/1.1\r\nHost: localhost\r\nConnection: close\r\n\r\n"
 
 
 def c_10():
-    c_style(HOST, PORT, req_10) 
+    c_style(HOST, PORT, req_10)
 
 
 def c_11():
-    c_style(HOST, PORT, req_11) 
+    c_style(HOST, PORT, req_11)
 
 
 def c_style(HOST, PORT, req):
 
     # Set up SSL context.
     ctx = m2.ssl_ctx_new(m2.sslv3_method())
-    m2.ssl_ctx_use_cert(ctx, 'client.pem')
-    m2.ssl_ctx_use_privkey(ctx, 'client.pem')
+    m2.ssl_ctx_use_cert(ctx, "client.pem")
+    m2.ssl_ctx_use_privkey(ctx, "client.pem")
 
     # Make the socket connection.
     s = socket(AF_INET, SOCK_STREAM)
@@ -54,7 +52,8 @@ def c_style(HOST, PORT, req):
     # Receive the response.
     while 1:
         data = m2.bio_gets(topbio, 4096)
-        if not data: break
+        if not data:
+            break
         sys.stdout.write(data)
 
     # Cleanup. May be missing some necessary steps. ;-|
@@ -66,7 +65,6 @@ def c_style(HOST, PORT, req):
     s.close()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     c_10()
     c_11()
-
