@@ -1,14 +1,16 @@
-"""M2Crypto.SSL.Session client demo: This program requests a URL from 
-a HTTPS server, saves the negotiated SSL session id, parses the HTML 
-returned by the server, then requests each HREF in a separate thread 
+from __future__ import print_function
+
+"""M2Crypto.SSL.Session client demo: This program requests a URL from
+a HTTPS server, saves the negotiated SSL session id, parses the HTML
+returned by the server, then requests each HREF in a separate thread
 using the saved SSL session id.
 
 Copyright (c) 1999-2003 Ng Pheng Siong. All rights reserved."""
 
-RCS_id='$Id: sess.py 299 2005-06-09 17:32:28Z heikki $'
-
 from M2Crypto import Err, Rand, SSL, X509, threading
-m2_threading = threading; del threading
+
+m2_threading = threading
+del threading
 
 import formatter, getopt, htmllib, sys
 from threading import Thread
@@ -24,7 +26,7 @@ def handler(sslctx, host, port, href, recurs=0, sslsess=None):
     else:
         s.connect((host, port))
         sslsess = s.get_session()
-    #print sslsess.as_text()
+    # print(sslsess.as_text())
 
     if recurs:
         p = htmllib.HTMLParser(formatter.NullFormatter())
@@ -47,45 +49,44 @@ def handler(sslctx, host, port, href, recurs=0, sslsess=None):
 
     if recurs:
         for a in p.anchorlist:
-            req = 'GET %s HTTP/1.0\r\n\r\n' % a
-            thr = Thread(target=handler, 
-                        args=(sslctx, host, port, req, recurs-1, sslsess))
-            print "Thread =", thr.getName()
+            req = "GET %s HTTP/1.0\r\n\r\n" % a
+            thr = Thread(
+                target=handler, args=(sslctx, host, port, req, recurs - 1, sslsess)
+            )
+            print("Thread =", thr.getName())
             thr.start()
-    
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
 
     m2_threading.init()
-    Rand.load_file('../randpool.dat', -1) 
+    Rand.load_file("../randpool.dat", -1)
 
-    host = '127.0.0.1'
+    host = "127.0.0.1"
     port = 9443
-    req = '/'
+    req = "/"
 
-    optlist, optarg = getopt.getopt(sys.argv[1:], 'h:p:r:')
+    optlist, optarg = getopt.getopt(sys.argv[1:], "h:p:r:")
     for opt in optlist:
-        if '-h' in opt:
+        if "-h" in opt:
             host = opt[1]
-        elif '-p' in opt:
+        elif "-p" in opt:
             port = int(opt[1])
-        elif '-r' in opt:
+        elif "-r" in opt:
             req = opt[1]
-    
-    ctx = SSL.Context('sslv3')
-    ctx.load_cert('client.pem')
-    ctx.load_verify_info('ca.pem')
-    ctx.load_client_ca('ca.pem')
+
+    ctx = SSL.Context("sslv3")
+    ctx.load_cert("client.pem")
+    ctx.load_verify_info("ca.pem")
+    ctx.load_client_ca("ca.pem")
     ctx.set_verify(SSL.verify_none, 10)
-    
-    req = 'GET %s HTTP/1.0\r\n\r\n' % req
+
+    req = "GET %s HTTP/1.0\r\n\r\n" % req
 
     start = Thread(target=handler, args=(ctx, host, port, req, 1))
-    print "Thread =", start.getName()
+    print("Thread =", start.getName())
     start.start()
     start.join()
-    
+
     m2_threading.cleanup()
-    Rand.save_file('../randpool.dat')
-
-
+    Rand.save_file("../randpool.dat")
