@@ -1,5 +1,3 @@
-from __future__ import absolute_import
-
 """M2Crypto wrapper for OpenSSL EVP API.
 
 Copyright (c) 1999-2004 Ng Pheng Siong. All rights reserved.
@@ -9,10 +7,10 @@ Author: Heikki Toivonen
 """
 
 import logging
-from M2Crypto import BIO, Err, RSA, EC, m2, util
+from M2Crypto import BIO, Err, RSA, EC, m2, util, types as C
 from typing import Optional, Callable, Union  # noqa
 
-log = logging.getLogger('EVP')
+log = logging.getLogger("EVP")
 
 
 class EVPError(ValueError):
@@ -22,9 +20,7 @@ class EVPError(ValueError):
 m2.evp_init(EVPError)
 
 
-def pbkdf2(
-    password: bytes, salt: bytes, iter: int, keylen: int
-) -> bytes:
+def pbkdf2(password: bytes, salt: bytes, iter: int, keylen: int) -> bytes:
     """
     Derive a key from password using PBKDF2 algorithm specified in RFC 2898.
 
@@ -42,7 +38,9 @@ class MessageDigest(object):
     Message Digest
     """
 
-    m2_md_ctx_free = m2.md_ctx_free
+    @staticmethod
+    def m2_md_ctx_free(ctx: C.EVP_MD_CTX) -> None:
+        m2.md_ctx_free(ctx)
 
     def __init__(self, algo: str) -> None:
         md: Optional[Callable] = getattr(m2, algo, None)
@@ -50,13 +48,15 @@ class MessageDigest(object):
             # if the digest algorithm isn't found as an attribute of the m2
             # module, try to look up the digest using get_digestbyname()
             self.md = m2.get_digestbyname(algo)
+            if self.md is None:
+                raise EVPError("unknown algorithm %s" % (algo,))
         else:
             self.md = md()
         self.ctx = m2.md_ctx_new()
         m2.digest_init(self.ctx, self.md)
 
     def __del__(self) -> None:
-        if getattr(self, 'ctx', None):
+        if getattr(self, "ctx", None):
             self.m2_md_ctx_free(self.ctx)
 
     def update(self, data: bytes) -> int:
@@ -76,18 +76,20 @@ class MessageDigest(object):
 
 class HMAC(object):
 
-    m2_hmac_ctx_free = m2.hmac_ctx_free
+    @staticmethod
+    def m2_hmac_ctx_free(ctx: C.HMAC_CTX) -> None:
+        m2.hmac_ctx_free(ctx)
 
-    def __init__(self, key: bytes, algo: str = 'sha1') -> None:
+    def __init__(self, key: bytes, algo: str = "sha256") -> None:
         md = getattr(m2, algo, None)
         if md is None:
-            raise ValueError('unknown algorithm', algo)
+            raise ValueError("unknown algorithm", algo)
         self.md = md()
         self.ctx = m2.hmac_ctx_new()
         m2.hmac_init(self.ctx, key, self.md)
 
     def __del__(self) -> None:
-        if getattr(self, 'ctx', None):
+        if getattr(self, "ctx", None):
             self.m2_hmac_ctx_free(self.ctx)
 
     def reset(self, key: bytes) -> None:
@@ -102,47 +104,47 @@ class HMAC(object):
     digest = final
 
 
-def hmac(key: bytes, data: bytes, algo: str = 'sha1') -> bytes:
+def hmac(key: bytes, data: bytes, algo: str = "sha256") -> bytes:
     md = getattr(m2, algo, None)
     if md is None:
-        raise ValueError('unknown algorithm', algo)
+        raise ValueError("unknown algorithm", algo)
     return m2.hmac(key, data, md())
 
 
 class Cipher(object):
 
-    m2_cipher_ctx_free = m2.cipher_ctx_free
+    @staticmethod
+    def m2_cipher_ctx_free(ctx: C.EVP_CIPHER_CTX) -> None:
+        m2.cipher_ctx_free(ctx)
 
     def __init__(
         self,
         alg: str,
         key: bytes,
         iv: bytes,
-        op: object,
+        op: int,
         key_as_bytes: int = 0,
-        d: str = 'md5',
-        salt: bytes = b'12345678',
+        d: str = "md5",
+        salt: bytes = b"12345678",
         i: int = 1,
         padding: int = 1,
     ) -> None:
         cipher = getattr(m2, alg, None)
         if cipher is None:
-            raise ValueError('unknown cipher', alg)
+            raise ValueError("unknown cipher", alg)
         self.cipher = cipher()
         if key_as_bytes:
             kmd = getattr(m2, d, None)
             if kmd is None:
-                raise ValueError('unknown message digest', d)
-            key = m2.bytes_to_key(
-                self.cipher, kmd(), key, salt, iv, i
-            )
+                raise ValueError("unknown message digest", d)
+            key = m2.bytes_to_key(self.cipher, kmd(), key, salt, iv, i)
         self.ctx = m2.cipher_ctx_new()
         m2.cipher_init(self.ctx, self.cipher, key, iv, op)
         self.set_padding(padding)
         del key
 
     def __del__(self) -> None:
-        if getattr(self, 'ctx', None):
+        if getattr(self, "ctx", None):
             self.m2_cipher_ctx_free(self.ctx)
 
     def update(self, data: bytes) -> bytes:
@@ -164,28 +166,33 @@ class PKey(object):
     as "key pairs").
     """
 
-    m2_pkey_free = m2.pkey_free
-    m2_md_ctx_free = m2.md_ctx_free
-
     def __init__(
         self,
-        pkey: Optional[bytes] = None,
+        pkey: Optional[C.EVP_PKEY] = None,
         _pyfree: int = 0,
-        md: str = 'sha1',
+        md: str = "sha256",
     ) -> None:
         if pkey is not None:
-            self.pkey: bytes = pkey
+            self.pkey = pkey
             self._pyfree = _pyfree
         else:
             self.pkey = m2.pkey_new()
             self._pyfree = 1
         self._set_context(md)
 
+    @staticmethod
+    def _m2_pkey_free(pkey: C.EVP_PKEY) -> None:
+        m2.pkey_free(pkey)
+
+    @staticmethod
+    def _m2_md_ctx_free(ctx: C.EVP_MD_CTX) -> None:
+        m2.md_ctx_free(ctx)
+
     def __del__(self) -> None:
-        if getattr(self, '_pyfree', 0):
-            self.m2_pkey_free(self.pkey)
-        if getattr(self, 'ctx', None):
-            self.m2_md_ctx_free(self.ctx)
+        if getattr(self, "_pyfree", 0):
+            self._m2_pkey_free(self.pkey)
+        if getattr(self, "ctx", None):
+            self._m2_md_ctx_free(self.ctx)
 
     def _ptr(self):
         return self.pkey
@@ -196,11 +203,11 @@ class PKey(object):
         else:
             mda: Optional[Callable] = getattr(m2, md, None)
             if mda is None:
-                raise ValueError('unknown message digest', md)
+                raise ValueError("unknown message digest", md)
             self.md = mda()
-        self.ctx: Context = m2.md_ctx_new()
+        self.ctx: C.EVP_MD_CTX = m2.md_ctx_new()
 
-    def reset_context(self, md: str = 'sha1') -> None:
+    def reset_context(self, md: str = "sha256") -> None:
         """
         Reset internal message digest context.
 
@@ -212,6 +219,8 @@ class PKey(object):
         """
         Initialise signing operation with self.
         """
+        if self.md is None:
+            raise EVPError("Digest algorithm not set")
         m2.sign_init(self.ctx, self.md)
 
     def sign_update(self, data: bytes) -> None:
@@ -238,6 +247,8 @@ class PKey(object):
         """
         Initialise signature verification operation with self.
         """
+        if self.md is None:
+            raise EVPError("Digest algorithm not set")
         m2.verify_init(self.ctx, self.md)
 
     def verify_update(self, data: bytes) -> int:
@@ -266,9 +277,7 @@ class PKey(object):
         if self.md is None:
             m2.digest_sign_init(self.ctx, self.pkey)
         else:
-            m2.digest_sign_init(
-                self.ctx, None, self.md, None, self.pkey
-            )
+            m2.digest_sign_init(self.ctx, None, self.md, None, self.pkey)
 
     def digest_sign_update(self, data: bytes) -> None:
         """
@@ -293,11 +302,10 @@ class PKey(object):
         :return: The signature.
         """
 
-        if m2.OPENSSL_VERSION_NUMBER < 0x10101000:
+        if not hasattr(m2, "digest_sign"):
             raise NotImplemented(
-                'This method requires OpenSSL version '
-                + '1.1.1 or greater.'
-            )
+                "This method requires OpenSSL version " + "1.1.1 or greater."
+            )  # type: ignore[misc]
 
         return m2.digest_sign(self.ctx, data)
 
@@ -308,9 +316,7 @@ class PKey(object):
         if self.md is None:
             m2.digest_verify_init(self.ctx, self.pkey)
         else:
-            m2.digest_verify_init(
-                self.ctx, None, self.md, None, self.pkey
-            )
+            m2.digest_verify_init(self.ctx, None, self.md, None, self.pkey)
 
     def digest_verify_update(self, data: bytes) -> int:
         """
@@ -341,11 +347,10 @@ class PKey(object):
                  other error.
         """
 
-        if m2.OPENSSL_VERSION_NUMBER < 0x10101000:
+        if not hasattr(m2, "digest_verify"):
             raise NotImplemented(
-                'This method requires OpenSSL version '
-                + '1.1.1 or greater.'
-            )
+                "This method requires OpenSSL version " + "1.1.1 or greater."
+            )  # type: ignore[misc]
 
         return m2.digest_verify(self.ctx, sign, data)
 
@@ -375,11 +380,13 @@ class PKey(object):
         instance is holding.
         """
         rsa_ptr = m2.pkey_get1_rsa(self.pkey)
+        if rsa_ptr is None:
+            raise EVPError("Not an RSA key")
 
         rsa = RSA.RSA_pub(rsa_ptr, 1)
         return rsa
 
-    def assign_ec(self, ec: EC.EC, capture: int = 1) -> int:
+    def assign_ec(self, ec: "EC.EC", capture: int = 1) -> int:
         """
         Assign the EC key pair to self.
 
@@ -399,20 +406,22 @@ class PKey(object):
             ret = m2.pkey_set1_ec(self.pkey, ec.ec)
         return ret
 
-    def get_ec(self) -> EC.EC_pub:
+    def get_ec(self) -> "EC.EC_pub":
         """
         Return the underlying EC key if that is what the EVP
         instance is holding.
         """
         ec_ptr = m2.pkey_get1_ec(self.pkey)
+        if ec_ptr is None:
+            raise ValueError("Not an EC key")
 
-        ec = EC.EC_pub(ec_ptr)
+        ec = EC.EC_pub(ec_ptr, 1)
         return ec
 
     def save_key(
         self,
         file: Union[str, bytes],
-        cipher: Optional[str] = 'aes_128_cbc',
+        cipher: Optional[str] = "aes_128_cbc",
         callback: Callable = util.passphrase_callback,
     ) -> int:
         """
@@ -429,13 +438,13 @@ class PKey(object):
                          the key. The default is
                          util.passphrase_callback.
         """
-        with BIO.openfile(file, 'wb') as bio:
+        with BIO.openfile(file, "wb") as bio:
             return self.save_key_bio(bio, cipher, callback)
 
     def save_key_bio(
         self,
         bio: BIO.BIO,
-        cipher: Optional[str] = 'aes_128_cbc',
+        cipher: Optional[str] = "aes_128_cbc",
         callback: Callable = util.passphrase_callback,
     ) -> int:
         """
@@ -453,20 +462,16 @@ class PKey(object):
                          util.passphrase_callback.
         """
         if cipher is None:
-            return m2.pkey_write_pem_no_cipher(
-                self.pkey, bio._ptr(), callback
-            )
+            return m2.pkey_write_pem_no_cipher(self.pkey, bio._ptr(), callback)
         else:
             proto = getattr(m2, cipher, None)
             if proto is None:
-                raise ValueError('no such cipher %s' % cipher)
-            return m2.pkey_write_pem(
-                self.pkey, bio._ptr(), proto(), callback
-            )
+                raise ValueError("no such cipher %s" % cipher)
+            return m2.pkey_write_pem(self.pkey, bio._ptr(), proto(), callback)
 
     def as_pem(
         self,
-        cipher: Optional[str] = 'aes_128_cbc',
+        cipher: Optional[str] = "aes_128_cbc",
         callback: Callable = util.passphrase_callback,
     ) -> bytes:
         """
@@ -505,6 +510,15 @@ class PKey(object):
         """
         return m2.pkey_get_modulus(self.pkey)
 
+    def get_key_identifier(self) -> bytes:
+        """
+        Return the Subject Key Identifier (SKID) calculated as the SHA-1
+        hash of the raw public key bytes (method 1 in RFC 5280, section 4.2.1.2).
+
+        :return: SHA1 digest (20 bytes) of the public key.
+        """
+        return m2.pkey_get_raw_pub_key_sha1(self.pkey)
+
 
 def load_key(
     file: Union[str, bytes],
@@ -521,7 +535,7 @@ def load_key(
 
     :return: M2Crypto.EVP.PKey object.
     """
-    with BIO.openfile(file, 'r') as bio:
+    with BIO.openfile(file, "r") as bio:
         cptr = m2.pkey_read_pem(bio.bio, callback)
 
     return PKey(cptr, 1)
@@ -543,16 +557,14 @@ def load_key_pubkey(
     :return: M2Crypto.EVP.PKey object.
     """
 
-    with BIO.openfile(file, 'r') as bio:
+    with BIO.openfile(file, "r") as bio:
         cptr = m2.pkey_read_pem_pubkey(bio._ptr(), callback)
         if cptr is None:
             raise EVPError(Err.get_error())
     return PKey(cptr, 1)
 
 
-def load_key_bio(
-    bio: BIO.BIO, callback: Callable = util.passphrase_callback
-) -> PKey:
+def load_key_bio(bio: BIO.BIO, callback: Callable = util.passphrase_callback) -> PKey:
     """
     Load an M2Crypto.EVP.PKey from an M2Crypto.BIO object.
 
@@ -603,7 +615,8 @@ def load_key_string(
 
     :return: M2Crypto.EVP.PKey object.
     """
-    bio = BIO.MemoryBuffer(string)
+    data = string.encode("utf8") if isinstance(string, str) else string
+    bio = BIO.MemoryBuffer(data)
     return load_key_bio(bio, callback)
 
 
@@ -622,5 +635,6 @@ def load_key_string_pubkey(
 
     :return: M2Crypto.EVP.PKey object.
     """
-    bio = BIO.MemoryBuffer(string)
+    data = string.encode("utf8") if isinstance(string, str) else string
+    bio = BIO.MemoryBuffer(data)
     return load_key_bio_pubkey(bio, callback)
