@@ -22,8 +22,8 @@ class UtilTestCase(unittest.TestCase):
             util.is_32bit()
             and (platform.libc_ver() != ("", ""))
             and (
-                os.environ.get('M2_TIMET_NO_ARCH', '').casefold()
-                not in ['true', '1', 'yes']
+                os.environ.get("M2_TIMET_NO_ARCH", "").casefold()
+                not in ["true", "1", "yes"]
             )
         ):
             self.assertEqual(bit32, 32)
@@ -36,7 +36,7 @@ def suite():
     return unittest.TestLoader().loadTestsFromTestCase(UtilTestCase)
 
 
-if __name__ == '__main__':
-    Rand.load_file('randpool.dat', -1)
+if __name__ == "__main__":
+    Rand.load_file("randpool.dat", -1)
     unittest.TextTestRunner().run(suite())
-    Rand.save_file('randpool.dat')
+    Rand.save_file("randpool.dat")
